@@ -1,7 +1,7 @@
 # Test::DistManifest
 #  Tests that your manifest matches the distribution as it exists.
 #
-# $Id: DistManifest.pm 10591 2009-12-22 14:32:00Z FREQUENCY@cpan.org $
+# $Id: DistManifest.pm 10663 2009-12-28 20:57:56Z FREQUENCY@cpan.org $
 
 package Test::DistManifest;
 
@@ -15,11 +15,11 @@ Test::DistManifest - Author test that validates a package MANIFEST
 
 =head1 VERSION
 
-Version 1.007 ($Id: DistManifest.pm 10591 2009-12-22 14:32:00Z FREQUENCY@cpan.org $)
+Version 1.008 ($Id: DistManifest.pm 10663 2009-12-28 20:57:56Z FREQUENCY@cpan.org $)
 
 =cut
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 $VERSION = eval $VERSION;
 
 =head1 EXPORTS
@@ -36,11 +36,11 @@ By default, this module exports the following functions:
 
 # File management commands
 use Cwd ();
-use File::Spec (); # Portability
-use File::Spec::Unix (); # To get UNIX-style paths
+use File::Spec; # Portability
+use File::Spec::Unix; # To get UNIX-style paths
 use File::Find (); # Traverse the filesystem tree
 
-use Module::Manifest ();
+use Module::Manifest;
 use Test::Builder;
 
 my $test = Test::Builder->new;
@@ -68,7 +68,6 @@ sub import {
   my $caller = caller;
 
   {
-    ## no critic (ProhibitNoStrict)
     no strict 'refs';
     for my $func (@EXPORTS) {
       *{$caller . '::' . $func} = \&{$func};
@@ -138,7 +137,9 @@ contact the maintainer.
 
 =head1 FUNCTIONS
 
-=head2 manifest_ok( $manifest , $skipfile )
+=head2 manifest_ok
+
+  manifest_ok( $manifest, $skipfile )
 
 This subroutine checks the manifest list contained in C<$manifest> by using
 C<Module::Manifest> to determine the list of files and then checking for the
@@ -146,12 +147,13 @@ existence of all such files. Then, it checks if there are any files in the
 distribution that were not specified in the C<$manifest> file but do not match
 any regular expressions provided in the C<$skipfile> exclusion file.
 
-If your MANIFEST file is generated by C<ExtUtils::MakeMaker> or
-C<Module::Build>, then you shouldn't have any problems with these files. It's
-just a helpful test to remind you to update these files, using:
+If your MANIFEST file is generated by a module installation toolchain system
+such as L<ExtUtils::MakeMaker>, L<Module::Build> or L<Module::Install>, then
+you shouldn't have any problems with these files. It's just a helpful test
+to remind you to update these files, using:
 
-  $ make dist # For ExtUtils::MakeMaker
-  $ ./Build dist # For Module::Build
+  $ make manifest # For ExtUtils::MakeMaker
+  $ ./Build manifest # For Module::Build
 
 =head2 Non-Fatal Errors
 
@@ -177,15 +179,12 @@ or from other shell scripts as:
 
   export MANIFEST_WARN_ONLY=1
 
-Note that parsing errors in each file (B<MANIFEST> and B<MANIFEST.SKIP>)
-and circular dependencies will always be considered fatal. The author is
-not aware of any cases where other behaviour would be useful.
+Note that parsing errors in B<MANIFEST> and circular dependencies will
+always be considered fatal. The author is not aware of any cases where
+other behaviour would be useful.
 
 =cut
 
-# It's not the simplest subroutine, but it's still not complex enough nor
-# useful enough in its parts to really be refactored.
-## no critic(ProhibitExcessComplexity)
 sub manifest_ok {
   my $warn_only = $ENV{MANIFEST_WARN_ONLY} || 0;
 
@@ -209,7 +208,7 @@ sub manifest_ok {
   $test->ok(!$@, 'Parse MANIFEST or equivalent');
 
   eval {
-    $manifest->open(skip     => $skipfile);
+    $manifest->open(skip => $skipfile);
   };
   if ($@) {
     $test->diag('Unable to parse MANIFEST.SKIP file:');
@@ -517,15 +516,13 @@ the module; the emphasis should be on generating helpful error messages.
 
 =head2 TEST COVERAGE
   
-  ----------------------- ------ ------ ------ ------ ------ ------
-  File                    stmt   bran   cond   sub    pod    total
+  File                     stmt   bran   cond   sub    pod   total
   ----------------------- ------ ------ ------ ------ ------ ------
   Test/DistManifest.pm    96.1   95.8   100.0  100.0  100.0  96.8
-  Total                   96.1   95.8   100.0  100.0  100.0  96.8
 
 =head1 LICENSE
 
-Copyright (C) 2008-2009 by Jonathan Yu <jawnsy@cpan.org>
+Copyright 2008-2009 by Jonathan Yu <jawnsy@cpan.org>
 
 This package is distributed under the same terms as Perl itself. Please
 see the F<LICENSE> file included in this distribution for full details of
